==> haskell-warp-3.3.31-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.3.31
visibility:           public
id:                   warp-3.3.31-LNQyGmUrjCg6zDV5km21Oc
key:                  warp-3.3.31-LNQyGmUrjCg6zDV5km21Oc
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  2edf5fa32e6cc940b588f22b8e907beb
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.31-LNQyGmUrjCg6zDV5km21Oc
depends:
    array-0.5.4.0 auto-update-0.1.6-E5Hf4yxUkLaAr1Mq4seJoW
    base-4.17.2.1 bsb-http-chunked-0.0.0.4-7NqGo2C0WupCxp8aE9wCow
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4NRudSZIbdgEwzMbC5HpSf
    containers-0.6.7 crypton-x509-1.7.7-9YYSsOOhQG44UhLazkZ1o3
    ghc-prim-0.9.1 hashable-1.4.6.0-2hEv5lQFD6LEJdTUNcXkaI
    http-date-0.0.11-Kqmg2dgqhYxKtXqUYD055s
    http-types-0.12.4-AnyveerSvWp9fcmJ7pBmmy
    http2-5.0.0-EgR5ptULoM5ECHO3gRUYSY
    iproute-1.7.15-7aTZHOuEG1sB8nT396gU7o
    network-3.1.4.0-4cEUA9pnnvEEvGlZk2FqT
    recv-0.1.1-Bdrt7wWz8CgDS87JP5ZYl2
    simple-sendfile-0.2.32-D3fiLGl8SIIEYQwU8If9dR stm-2.5.1.0
    streaming-commons-0.2.3.0-1pdd29y7T8I9mgxMzjHfTV text-2.0.2
    time-manager-0.0.1-LeUNwnwlkYf5zClYZEvcFy unix-2.7.3
    unliftio-0.2.25.1-DyweKXwNyOA6bCdvyvzfdZ
    vault-0.3.1.5-Kyx3ctxvUVf1IygSqtcXs
    wai-3.2.4-6yvNKQ0UUswJzjrPe1tuVO word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.3.31-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.3.31
visibility:           public
id:                   warp-3.3.31-KE5H9mDCEjAKQ3W6oJRFhX
key:                  warp-3.3.31-KE5H9mDCEjAKQ3W6oJRFhX
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  13b99ef0aee1aa86d447888633e693c2
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-3.3.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.3.31-KE5H9mDCEjAKQ3W6oJRFhX
depends:
    array-0.5.4.0 auto-update-0.1.6-4130TMPnIqX6bIh71QvxWp
    base-4.17.2.1 bsb-http-chunked-0.0.0.4-CmClRw56xW22dfhdu2rqYX
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Fpgl4YyjrVl4Gttb0PploH
    containers-0.6.7 crypton-x509-1.7.7-FRb1RijBp4iFIzTgEXXpQA
    ghc-prim-0.9.1 hashable-1.4.6.0-JiQr1Tltq7G4W5bcwnoSMj
    http-date-0.0.11-IpJwVRA3uG0HzRuyeSH8ON
    http-types-0.12.4-8HR0lcMpUwL4edtlDqx8uG
    http2-5.0.0-DkjG5ko8ADo9m40JTjBiEU
    iproute-1.7.15-Jg66qI2v789fAQZ9uaGQd
    network-3.1.4.0-4UbSgXPdAp7DQ7Pftr1aPB
    recv-0.1.1-E2j9i7LeKkC10CErXYGh0V
    simple-sendfile-0.2.32-GCnWB1lP32A7nSaUQXPuSo stm-2.5.1.0
    streaming-commons-0.2.3.0-6tmXzasKW9zLKItks2OjAF text-2.0.2
    time-manager-0.0.1-Hkqm4UvIJRuFJLefEeGun4 unix-2.7.3
    unliftio-0.2.25.1-K65YKtoeNxU8ODiXOzaxtw
    vault-0.3.1.5-AgnXc00klW2H4jZnXS8V8g
    wai-3.2.4-54grchYoKyyD66je19YTSn word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
